@@ -1,7 +1,5 @@
-# ========================  STATE SEQUENCE INDIVIDUAL  ==========================
-# Derives from Bdata$path the sequence of states in numeric values
-# .... path.num = sequence of states occupied by respondent i ( 1 =1,nsample) .......
-Sequences.ind <- function(path,namstatesnew)
+Sequences.ind <-
+function(path,namstatesnew)
 { if (missing(namstatesnew))  if (exists ("namstates")) namstatesnew <- namstates else stop ("Sequences.ind: namstates is missing")
   path <- as.character(path)
   nsample<-length(path)
@@ -15,4 +13,4 @@ Sequences.ind <- function(path,namstatesnew)
         }
    }
   return (seq.ind=path.num)
-}
\ No newline at end of file
+}
