@@ -2,9 +2,8 @@ pos.char <-
 function(string,char)
 {  zz <- stringf(as.character(string))
    if (char%in%zz)
-     { z <- grep(char,zz)}  else
+     { z <- which (zz==char)}  else
        { z <- NA }
-    z1<- z[1] # returns first occurrence only
-   return (z1)
+    # returns all occurrences
+   return (z[1])
 }
-
